@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta;
 
-our $VERSION = '2.150003'; # TRIAL
+our $VERSION = '2.150004'; # TRIAL
 
 #pod =head1 SYNOPSIS
 #pod
@@ -650,7 +650,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.150003
+version 2.150004
 
 =head1 SYNOPSIS
 
@@ -1007,7 +1007,7 @@ L<CPAN::Meta::Validator>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/Perl-Toolchain-Gang/cpan-meta/issues>.
+at L<https://github.com/Perl-Toolchain-Gang/CPAN-Meta/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -1015,9 +1015,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/Perl-Toolchain-Gang/cpan-meta>
+L<https://github.com/Perl-Toolchain-Gang/CPAN-Meta>
 
-  git clone https://github.com/Perl-Toolchain-Gang/cpan-meta.git
+  git clone https://github.com/Perl-Toolchain-Gang/CPAN-Meta.git
 
 =head1 AUTHORS
 
@@ -1035,7 +1035,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ansgar Burchardt Avar Arnfjord Bjarmason Christopher J. Madsen Chuck Adams Cory G Watson Damyan Ivanov Eric Wilhelm Graham Knop Gregor Hermann Karen Etheridge Kenichi Ishigaki Ken Williams Lars Dieckow Leon Timmermans majensen Mark Fowler Matt S Trout Michael G. Schwern mohawk2 moznion Olaf Alders Olivier Mengue Randy Sims
+=for stopwords Ansgar Burchardt Avar Arnfjord Bjarmason Christopher J. Madsen Chuck Adams Cory G Watson Damyan Ivanov Eric Wilhelm Graham Knop Gregor Hermann Karen Etheridge Kenichi Ishigaki Ken Williams Lars Dieckow Leon Timmermans majensen Mark Fowler Matt S Trout Michael G. Schwern mohawk2 moznion Niko Tyni Olaf Alders Olivier Mengue Randy Sims Tomohiro Hosaka
 
 =over 4
 
@@ -1121,6 +1121,10 @@ moznion <moznion@gmail.com>
 
 =item *
 
+Niko Tyni <ntyni@debian.org>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -1131,6 +1135,10 @@ Olivier Mengue <dolmen@cpan.org>
 
 Randy Sims <randys@thepierianspring.org>
 
+=item *
+
+Tomohiro Hosaka <bokutin@bokut.in>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
